<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Admin Class
 *
 * Handles generic Admin functionality and AJAX requests.
 *
 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
 */
class WOO_Vou_Pf_Admin {
	
	public function __construct() {
		
	}		
	
	/**
	 * Add Pdf fonts settings
	 * 
	 * Handle to add more pdf fonts to support all languages character
	 *
	 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	function woo_vou_pf_settings( $woo_vou_settings ) {

		// define all pdf fonts
		$all_pdf_fonts = array(
			''				=> __( 'Please Select', 'woovoucherpf' ),
			'General Fonts'		=> array(
				'courier' 		=> 'Courier',
				'courierB' 		=> 'Courier Bold',
				'courierBI' 	=> 'Courier Bold Italic',
				'courierI' 		=> 'Courier Italic',							
				'helveticaB' 	=> 'Helvetica Bold',
				'helveticaBI' 	=> 'Helvetica Bold Italic',
				'helveticaI' 	=> 'Helvetica Italic',
				'times' 		=> 'Times New Roman',
				'timesB' 		=> 'Times New Roman Bold',
				'timesBI' 		=> 'Times New Roman Bold Italic',
				'timesI' 		=> 'Times New Roman Italic',
				'myriad'		=> 'Myriad'
			),
			'Symbolic Fonts'	=> array(
				'symbol' 		=> 'Symbol',							
				'zapfdingbats' 	=> 'Zapf Dingbats',	
			),
			'Persian and Arabic language Fonts' => array(
				'freeserif'		=> 'freeserif (Suppot most of the languages)'
			),
			'CID-0 CJK Fonts'	=> array(								
				'cid0jp'		=> 'cid0jp (Chinese & Japanese)',
				'cid0kr'		=> 'cid0kr (Korean)'
			),
			'custom'			=> __( 'Custom Font', 'woovoucherpf' ),
		);

		// define settings to add pdf font select box	
		$woo_vou_pdf_font_settings = array( 
			array(
				'id'		=> 'vou_pdf_font',
				'name'		=> __( 'Font', 'woovoucherpf' ),
				'desc'		=> '<p class="description">'.__( 'Select fonts for character support for PDF voucher. If you select  <strong>Custom Font</strong> option then you need to put font in <code>wp-content/woocommerce-pdf-vouchers/fonts</code> folder.', 'woovoucherpf' ).'</p>',
				'type'		=> 'vou_pf_select_box',
				'class'		=> 'wc-enhanced-select',
				'options'	=> $all_pdf_fonts,
				'default'	=> 'freeserif'
			),
			array(
				'id'		=> 'vou_custom_font_name_option',
				'name'		=> __( 'Custom Font Name', 'woovoucher' ),
				'desc'		=> __( 'Enter the name of your custom font. Make sure you enter the font name correctly.', 'woovoucherpf' ),
				'type'		=> 'vou_filename',
				'default'   => '',
				'desc_tip'	=> ''
				), 
		);

		// merge settings									
		array_splice( $woo_vou_settings, 6, 0, $woo_vou_pdf_font_settings ); // splice in at position 2

		return $woo_vou_settings;
	}
	
	/**
	 * Add Custom select box 	 
	 *
	 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function woo_vou_pf_admin_field_vou_pf_select_box( $field ) {
		
		$defaults = array(
			'title'             => '',
			'disabled'          => false,
			'class'             => '',
			'css'               => '',
			'placeholder'       => '',
			'type'              => 'text',
			'desc_tip'          => false,
			'description'       => '',
			'custom_attributes' => array(),
			'options'           => array(),
		);

		$field = wp_parse_args( $field, $defaults );

		if ( isset( $field['type'] ) && $field['type'] == 'vou_pf_select_box' ) : 
			
			$field_value	= get_option( $field['id'] );
			
			if( empty( $field_value ) ) {
				$field_value	= $field['default'];
			}
			
			?>			
			
			<tr valign="top">
				<th scope="row" class="titledesc">
					<label for="<?php echo esc_attr( $field['id'] ); ?>"><?php echo wp_kses_post( $field['title'] ); ?></label>					
				</th>
				<td class="forminp forminp-text">
					<fieldset>
						<legend class="screen-reader-text"><span><?php echo wp_kses_post( $field['title'] ); ?></span></legend>
						<select id="<?php echo esc_attr( $field['id'] ); ?>" class="select <?php echo esc_attr( $field['class'] ); ?>" title="<?php echo esc_attr( $field['name'] ); ?>" name="<?php echo esc_attr( $field['id'] ); ?>">
						<?php 
							foreach ( (array) $field['options'] as $option_key => $option_value ) :
								if( is_array( $option_value ) ) { ?>
									<optgroup label="<?php echo $option_key; ?>">
										<?php foreach ( $option_value as $second_option_key => $second_option_value ) : ?>
											<option value="<?php echo esc_attr( $second_option_key ); ?>" <?php selected( $second_option_key, esc_attr( $field_value ) ); ?>><?php echo esc_attr( $second_option_value ); ?></option>
										<?php endforeach; ?>
									</optgroup>
								<?php } else { ?>
									<option value="<?php echo esc_attr( $option_key ); ?>" <?php selected( $option_key, esc_attr( $field_value ) ); ?>><?php echo esc_attr( $option_value ); ?></option>
								<?php } ?>
						<?php endforeach; ?>
						</select>
					</fieldset>
					<span class="description"><?php echo $field['desc'];?></span>
				</td>
			</tr><?php
		
		endif;		
	}
	
	/**
	 * Save Custom select box 	 
	 *
	 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function woo_vou_pf_save_vou_pf_select_box( $field ) {

		if ( isset( $_POST[ $field['id'] ] ) ) {
			update_option( $field['id'], $_POST[ $field['id']] );
		}
	}
	
	/**
	 * Change pdf fonts path	 
	 *
	 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function woo_vou_pf_tcpdf_font_path( $tcpdf_fonts_path ) {

		global $pdf_template_id;
		
		// getting character support
		$voucher_char_support = get_option( 'vou_char_support' );

		// get font from global setting
		$vou_pdf_font = get_option( 'vou_pdf_font' );
		if( !empty($pdf_template_id) ) {
			$prefix = WOO_VOU_META_PREFIX;
			$metaFont = get_post_meta( $pdf_template_id, $prefix . 'pdf_font', true );

			$vou_pdf_font = !empty( $metaFont ) ? $metaFont : $vou_pdf_font;
		}
		
		// check if its selected, yes then chage fonts path to this addon
		if( !empty( $voucher_char_support) && $voucher_char_support == 'yes' ) {
			
			// if custom font selected then load from wp-content/woocommerce-pdf-vouchers/fonts to prevent loss on update of plugin
			$customFontDir = WP_CONTENT_DIR .'/woocommerce-pdf-vouchers/fonts';
			if( $vou_pdf_font == 'custom' && is_dir( $customFontDir )) { 
				$fdir = WP_CONTENT_DIR .'/woocommerce-pdf-vouchers/fonts';
			} else {
				$fdir = realpath( WOO_VOU_PF_DIR.'/includes/tcpdf/fonts' );
			}
			if (substr($fdir, -1) != '/') {
				$fdir .= '/';
			}
			$tcpdf_fonts_path = $fdir;

		}				
		
		return  $tcpdf_fonts_path;
	}
	
	/**
	 * Add metabox for pdf font selection in voucher template
	 *
	 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function woo_vou_pf_add_meta_box(){
		
		$voucher_char_support = get_option( 'vou_char_support' );
		
		if( empty( $voucher_char_support ) || $voucher_char_support == 'no' ) return;
		
		add_meta_box( 'woo_vou_pf_pdf_fonts_meta' ,__( 'Font', 'woovoucher' ), array( $this, 'woo_vou_pf_pdf_fonts_meta' ), WOO_VOU_POST_TYPE, 'normal', 'low', 1 );
	}
	
	/**
	 * Metabox content for pdf font selection in voucher template
	 *
	 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function woo_vou_pf_pdf_fonts_meta(){
		
		$prefix = WOO_VOU_META_PREFIX;
		
		// define all pdf fonts
		$all_pdf_fonts = array(
			''				=> __( 'Please Select', 'woovoucherpf' ),
			'General Fonts'		=> array(
				'courier' 		=> 'Courier',
				'courierB' 		=> 'Courier Bold',
				'courierBI' 	=> 'Courier Bold Italic',
				'courierI' 		=> 'Courier Italic',							
				'helveticaB' 	=> 'Helvetica Bold',
				'helveticaBI' 	=> 'Helvetica Bold Italic',
				'helveticaI' 	=> 'Helvetica Italic',
				'times' 		=> 'Times New Roman',
				'timesB' 		=> 'Times New Roman Bold',
				'timesBI' 		=> 'Times New Roman Bold Italic',
				'timesI' 		=> 'Times New Roman Italic',
				'myriad'		=> 'Myriad'
			),
			'Symbolic Fonts'	=> array(
				'symbol' 		=> 'Symbol',							
				'zapfdingbats' 	=> 'Zapf Dingbats',	
			),
			'Persian and Arabic language Fonts' => array(
				'freeserif'		=> 'freeserif (Suppot most of the languages)'
			),
			'CID-0 CJK Fonts'	=> array(								
				'cid0jp'		=> 'cid0jp (Chinese & Japanese)',
				'cid0kr'		=> 'cid0kr (Korean)'
			),
			'custom'			=> __( 'Custom Font', 'woovoucherpf' ),
		);
		
		woo_vou_content_begin();
		
		$this->woo_vou_pf_add_select( array( 'id' => $prefix . 'pdf_font', 'style' => 'width:60%; min-width:200px; float: left;', 'class' => 'regular-text wc-enhanced-select woo_vou_pdf_font', 'name'=> __( 'Font:', 'woovoucherpf' ), 'options' => $all_pdf_fonts, 'desc' => __( 'Select fonts for character support for PDF voucher. If you select  <strong>Custom Font</strong> option then you need to put font in <code>wp-content/woocommerce-pdf-vouchers/fonts</code> folder.', 'woovoucherpf' ) ) );

		$this->woo_vou_pf_add_text( array( 'id' => $prefix . 'pdf_template_custom_font', 'class' => 'regular-text pdf_template_custom_font', 'name'=> __( 'Custom Font Name:', 'woovoucherpf' ), 'desc' => __( 'Enter the name of your custom font. Make sure you enter the font name correctly.', 'woovoucherpf' ), 'field_desc' => '' ) );

		woo_vou_content_end();
	}
	
	/**
	 * Show Field Select.
	 *
	 * @param string $field 
	 * @param string $meta 
	 * @since 1.0
	 * @access public
	 */
	function woo_vou_pf_add_select( $args, $echo = true ) {
		
		$html = '';
		
		$new_field = array( 'type' => 'select', 'name' => 'Select Field', 'multiple' => false, 'style' => '' );
		$field = array_merge( $new_field, $args );
		
		$default_meta = isset( $field['default'] ) ? $field['default'] : '';
		
		$meta = woo_vou_meta_value( $field );
		$meta = !empty( $meta ) ? $meta : $default_meta;
		
		if( ! is_array( $meta ) ) {
			$meta = (array) $meta;
		}
		
		$html .= woo_vou_show_field_begin( $field );
		
		$html .= "<select class='woo-vou-meta-select {$field['class']} ".($field['multiple'] ? 'woo-vou-meta-multiple-select' : 'woo-vou-meta-single-select')."' name='{$field['id']}" . ( $field['multiple'] ? "[]' id='{$field['id']}' multiple='multiple'" : "'" ) . " style='" . esc_attr( $field['style'] ) . "'>";
		
		foreach ( (array) $field['options'] as $option_key => $option_value ) :
			if( is_array( $option_value ) ) {
				$html .= '<optgroup label="'.$option_key.'">';
					foreach ( $option_value as $second_option_key => $second_option_value ) :
						$html .= "<option value='".esc_attr( $second_option_key )."' ".selected( $second_option_key, esc_attr( $meta[0] ), false ).">".esc_attr( $second_option_value )."</option>";
					endforeach;
				$html .= '</optgroup>';
			} else {
				$html .= "<option value='".esc_attr( $option_key )."' ".selected( $option_key, esc_attr( $meta[0] ), false ).">".esc_attr( $option_value )."</option>";
			}
		endforeach;
		
		$html .= "</select>";	
			
		$html .= woo_vou_show_field_end( $field );
		
		if($echo) {
			echo $html;
		} else {
			return $html;
		}
		
	}

	/**
	 * Show text Field.
	 *
	 * @param string $args
	 * @param string $echo 
	 * @since 2.8.2
	 * @access public
	 */
	function woo_vou_pf_add_text( $args, $echo = true ){

		$html = '';
	
		$new_field = array( 'type' => 'text', 'name' => 'Text Field', 'field_desc' => '', 'class' => '' );
		$field = array_merge( $new_field, $args );
		
		$meta = woo_vou_meta_value( $field );
		
		$html .= woo_vou_show_field_begin( $field );
		
		$html .= "<input type='text' class='woo-vou-meta-text {$field['class']}' name='{$field['id']}' id='{$field['id']}' value='{$meta}' />";
		$html .= $field['field_desc'];
		
		$html .= woo_vou_show_field_end( $field );
		
		if($echo) {
			echo $html;
		} else {
			return $html;
		}
		
	}

	
	/**
	 * Save Voucher Meta Content
	 * 
	 * Handles to saving voucher meta on update voucher template post type
	 * 
	 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function woo_vou_pf_save_metadata( $post_id ){
		
		global $post_type;
		
		$prefix = WOO_VOU_META_PREFIX;
		
		$post_type_object = get_post_type_object( $post_type );
		
		// Check for which post type we need to add the meta box
		$pages = array( WOO_VOU_POST_TYPE );
		
		if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )                // Check Autosave
		|| ( ! isset( $_POST['post_ID'] ) || $post_id != $_POST['post_ID'] )        // Check Revision
		|| ( ! in_array( $post_type, $pages ) )              // Check if current post type is supported.
		|| ( ! check_admin_referer( WOO_VOU_PLUGIN_BASENAME, 'at_woo_vou_meta_box_nonce') )      // Check nonce - Security
		|| ( ! current_user_can( $post_type_object->cap->edit_post, $post_id ) ) )       // Check permission
		{
			return $post_id;
		}
		
		//Update Margin Right
		if( isset( $_POST[ $prefix . 'pdf_font' ] ) ) {
			update_post_meta( $post_id, $prefix . 'pdf_font', $_POST[ $prefix . 'pdf_font' ] );
		}

		if( isset( $_POST[ $prefix . 'pdf_template_custom_font' ] ) ) {
			update_post_meta( $post_id, $prefix . 'pdf_template_custom_font', $_POST[ $prefix . 'pdf_template_custom_font' ] );
		}
	}
	
	/**
	 * Add filter to get pdf font
	 *
	 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function woo_vou_pf_generate_fonts( $pdf_font, $template_id = '' ){

		global $pdf_template_id;

		$pdf_template_id = ( !empty($template_id) ) ? $template_id : $pdf_template_id;
		
		$prefix = WOO_VOU_META_PREFIX;
		
		// getting character support
		$voucher_char_support = get_option( 'vou_char_support' );
		
		if( $voucher_char_support == 'yes' ) { // if charactor support is enable
			
			// get font from global setting
			$vou_pdf_font	= get_option( 'vou_pdf_font' );

			// if custom font is selected than get font name from custom text box
			if ( $vou_pdf_font == 'custom') {
				$vou_pdf_font = $pdf_font;
				if( is_dir(WP_CONTENT_DIR .'/woocommerce-pdf-vouchers/fonts') ){
					$vou_pdf_font = get_option( 'vou_custom_font_name_option' );
				}
			}
			
			if( !empty( $pdf_template_id ) ) { // if template is not empty
				
				// get font from voucher template meta field
				$vou_pdf_font_meta = get_post_meta( $pdf_template_id, $prefix . 'pdf_font', true );
				
				// if custom font is selected from voucher template meta field than get font name from custom text box in meta field
				if ( $vou_pdf_font_meta == 'custom') {
					$vou_pdf_font_meta = get_post_meta( $pdf_template_id, $prefix . 'pdf_template_custom_font', true );
				}

				if( !empty( $vou_pdf_font_meta ) ) { // if meta value is not empty
					$vou_pdf_font = $vou_pdf_font_meta;
				}
			}
			
			if( !empty( $vou_pdf_font ) ) {
				$pdf_font = $vou_pdf_font;
			}
		}
		
		return $pdf_font;
	}
	
	/**
	 * Adding Hooks
	 *
	 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
	 * @since 1.0.0
	 */
	public function add_hooks() {
		
		// add filter to add more fonts for language support		
		add_filter( 'woo_vou_misc_settings', array( $this, 'woo_vou_pf_settings' ) );
		
		// add action to add custom field (select box with option group)
		add_action( 'woocommerce_admin_field_vou_pf_select_box', array( $this, 'woo_vou_pf_admin_field_vou_pf_select_box' ) );
		
		// add filter to change pdf font path
		add_filter( 'woo_vou_tcpdf_fonts_path', array( $this, 'woo_vou_pf_tcpdf_font_path' ) );
		
		// Add metabox for pdf font selection in voucher template
		add_action( 'add_meta_boxes', array( $this, 'woo_vou_pf_add_meta_box' ) );
		
		// Saving voucher meta on update or publish voucher template post type
		add_action( 'save_post', array( $this, 'woo_vou_pf_save_metadata' ) );
		
		// Add filter to get pdf font
		add_filter( 'woo_vou_pdf_generate_fonts', array( $this, 'woo_vou_pf_generate_fonts' ), 10, 2 );

		// To change default font from TCPDF
		add_filter( 'woo_vou_tcpdf_main_font', array( $this, 'woo_vou_pf_generate_fonts' ), 10, 1 );
		add_filter( 'woo_vou_tcpdf_data_font', array( $this, 'woo_vou_pf_generate_fonts' ), 10, 1 );
	}
}