<?php
/**
 * Plugin Name: WooCommerce PDF Vouchers - Multi Language Characters Support
 * Plugin URI:  https://wpwebelite.com/
 * Description: Adds Multi Language Characters Support for pdf vouchers.
 * Version: 1.0.7
 * Author: WPWeb
 * Author URI: https://wpwebelite.com/
 * Text Domain: woovoucherpf
 * Domain Path: languages
 * Tested up to: 5.5.1
 * WC tested up to: 5.7.2
 * 
 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
 * @category Core
 * @author WPWeb
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Basic plugin definitions
 * 
 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
 */
if( !defined( 'WOO_VOU_PF_PLUGIN_VERSION' ) ) {
	define( 'WOO_VOU_PF_PLUGIN_VERSION', '1.0.7' ); //Plugin version number
}
if( !defined( 'WOO_VOU_PF_DIR' ) ) {
	define( 'WOO_VOU_PF_DIR', dirname( __FILE__ ) ); // plugin dir
}
if( !defined( 'WOO_VOU_PF_URL' ) ) {
	define( 'WOO_VOU_PF_URL', plugin_dir_url( __FILE__ ) ); // plugin url
}
if( !defined( 'WOO_VOU_PF_ADMIN' ) ) {
	define( 'WOO_VOU_PF_ADMIN', WOO_VOU_PF_DIR . '/includes/admin' ); // plugin admin dir
}
if( !defined( 'WOO_VOU_PF_PLUGIN_BASENAME' ) ) {
	define( 'WOO_VOU_PF_PLUGIN_BASENAME', basename( WOO_VOU_PF_DIR ) ); //Plugin base name
}
if ( ! defined( 'WOO_VOU_PF_PLUGIN_KEY' ) ) {
	define( 'WOO_VOU_PF_PLUGIN_KEY', 'woopfvouchers' );
}

/**
 * Admin notices
 *
 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
*/
function woo_vou_pf_admin_notices() {
	if( !defined( WOO_VOU_DIR ) ) {	
		echo '<div class="error">';
		echo "<p><strong>" . __( 'Woocommerce PDF Vouchers needs to be activated to be able to use the Woocommerce PDF Voucher PDF Fonts.', 'woovoucherpf' ) . "</strong></p>";
		echo '</div>';
	}
}

/**
 * Check WooCommerce PDF Vouchers Plugin
 *
 * Handles to check Easy Digital Downloads plugin
 * if not activated then deactivate our plugin
 *
 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
 */
function woo_vou_pf_check_activation() {

	// Check if constants are defined and PDF Vouchers plugin is active
	if ( !defined('WOO_VOU_PLUGIN_BASENAME') && !defined('WOO_VOU_PLUGIN_BASE_FILENAME') 
		&& !is_plugin_active('woocommerce-pdf-vouchers/woocommerce-pdf-vouchers.php') ) {

		// is this plugin active?
		if( is_plugin_active( plugin_basename( __FILE__ ) ) ) {
			// deactivate the plugin
	 		deactivate_plugins( plugin_basename( __FILE__ ) );
	 		// unset activation notice
	 		unset( $_GET[ 'activate' ] );
	 		// display notice
	 		add_action( 'admin_notices', 'woo_vou_pf_admin_notices' );
		}
	}
}
//Check Easy Digital Downloads plugin is Activated or not
add_action( 'admin_init', 'woo_vou_pf_check_activation' );

/**
 * Deactivation Hook
 * 
 * Register plugin deactivation hook.
 * 
 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
 *  @since 1.0.3
 */
register_deactivation_hook( __FILE__, 'woo_vou_pf_uninstall' );

/**
 * Plugin Setup (On Deactivation)
 * 
 * Delete  plugin options.
 * 
 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
 * @since 1.0.3
 */
function woo_vou_pf_uninstall() {
	global $wpdb;

	// delete global settings
	delete_option( 'vou_pdf_font' );
	delete_option( 'vou_custom_font_name_option' );

	// post meta table
	$tableName = $wpdb->prefix . 'postmeta';

	// Delete metaboxes
	$wpdb->query( "DELETE FROM `{$tableName}` WHERE meta_key = '_woo_vou_pdf_font' OR meta_key = '_woo_vou_pdf_template_custom_font'" );
}

/**
 * Load Text Domain
 * 
 * This gets the plugin ready for translation.
 * 
 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
 */
function woo_vou_pf_load_text_domain() {
	
	// Set filter for plugin's languages directory
	$woo_vou_pf_lang_dir	= dirname( plugin_basename( __FILE__ ) ) . '/languages/';
	$woo_vou_pf_lang_dir	= apply_filters( 'woo_vou_pf_languages_directory', $woo_vou_pf_lang_dir );
	
	// Traditional WordPress plugin locale filter
	$locale	= apply_filters( 'plugin_locale',  get_locale(), 'woovoucher' );
	$mofile	= sprintf( '%1$s-%2$s.mo', 'woovoucherpf', $locale );
	
	// Setup paths to current locale file
	$mofile_local	= $woo_vou_pf_lang_dir . $mofile;
	$mofile_global	= WP_LANG_DIR . '/' . WOO_VOU_PF_PLUGIN_BASENAME . '/' . $mofile;
	
	if ( file_exists( $mofile_global ) ) { // Look in global /wp-content/languages/woocommerce-pdf-vouchers-pdf-fonts folder
		load_textdomain( 'woovoucherpf', $mofile_global );
	} elseif ( file_exists( $mofile_local ) ) { // Look in local /wp-content/plugins/woocommerce-pdf-vouchers-pdf-fonts/languages/ folder
		load_textdomain( 'woovoucherpf', $mofile_local );
	} else { // Load the default language files
		load_plugin_textdomain( 'woovoucherpf', false, $woo_vou_pf_lang_dir );
	}
}

//add action to load plugin
add_action( 'plugins_loaded', 'woo_vou_pf_plugin_loaded', 999 );

/**
 * Load Plugin
 * 
 * Handles to load plugin after
 * dependent plugin is loaded
 * successfully
 * 
 * @package WooCommerce PDF Vouchers - Multi Language Characters Support
 * @since 1.0.0
 */
function woo_vou_pf_plugin_loaded() {

	//check Woocommerce is activated or not
	if( class_exists( 'Woocommerce' ) ) {
		
		// load first plugin text domain
		woo_vou_pf_load_text_domain();
		
		global $woo_vou_pf_admin, $woo_vou_pf_scripts;
		
		//Admin Pages Class for admin side
		require_once( WOO_VOU_PF_ADMIN . '/class-woo-vou-pf-admin.php' );
		$woo_vou_pf_admin = new WOO_Vou_Pf_Admin();
		$woo_vou_pf_admin->add_hooks();

		//Script Pages Class for admin side
		require_once( WOO_VOU_PF_DIR . '/includes/class-woo-vou-pf-scripts.php' );
		$woo_vou_pf_scripts = new WOO_Vou_Pf_Script();
		$woo_vou_pf_scripts->add_hooks();
		
	} //end if to check class Woocommerce is exist or not

	if( defined( 'WOO_VOU_WPWEB_UPD_DIR' ) ) {
	
		// Plugin updates
		wpweb_queue_update( plugin_basename( __FILE__ ), WOO_VOU_PF_PLUGIN_KEY );

		include_once( WOO_VOU_WPWEB_UPD_DIR . '/updates/class-plugin-update-checker.php' );
		
		$WpwebWoovouPdfFontsUpdateChecker = new WpwebPluginUpdateChecker(
			WPWEB_UPD_DOMAIN . '/Updates/WOOVouchersPdfFonts/info.json',
			__FILE__,
			WOO_VOU_PF_PLUGIN_KEY
		);
	}
	
} //end if to check plugin loaded is called or not

/**
* Declare compatible with HPOS
* 
* @package WooCommerce PDF vouchers - OTP on redemption
* @since 1.0.5
*/
add_action( 'before_woocommerce_init', function() {
	if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
		\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
	}
} );